@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -13,7 +13,7 @@
  | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
  | GNU General Public License for more details.                            |
  +-------------------------------------------------------------------------+
- | Cacti: The Complete RRDTool-based Graphing Solution                     |
+ | Cacti: The Complete RRDtool-based Graphing Solution                     |
  +-------------------------------------------------------------------------+
  | This code is designed, written, and maintained by the Cacti Group. See  |
  | about.php and/or the AUTHORS file for specific developer information.   |
@@ -91,7 +91,7 @@ function form_save() {
 	// sanitize ids
 	if (isset_request_var('graph_template_id') && !is_numeric(get_nfilter_request_var('graph_template_id'))) {
 		$graph_template_id = 0;
-	}else{
+	} else {
 		$graph_template_id = get_filter_request_var('graph_template_id');
 	}
 
@@ -100,9 +100,10 @@ function form_save() {
 		get_filter_request_var('graph_template_graph_id');
 		/* ==================================================== */
 
-		$save1['id']   = $graph_template_id;
-		$save1['hash'] = get_hash_graph_template($graph_template_id);
-		$save1['name'] = form_input_validate(get_nfilter_request_var('name'), 'name', '', false, 3);
+		$save1['id']       = $graph_template_id;
+		$save1['hash']     = get_hash_graph_template($graph_template_id);
+		$save1['name']     = form_input_validate(get_nfilter_request_var('name'), 'name', '', false, 3);
+		$save1['multiple'] = isset_request_var('multiple') ? 'on':'';
 
 		$save2['id']                     = get_nfilter_request_var('graph_template_graph_id');
 		$save2['local_graph_template_graph_id'] = 0;
@@ -173,7 +174,7 @@ function form_save() {
 
 			if ($graph_template_id) {
 				raise_message(1);
-			}else{
+			} else {
 				raise_message(2);
 			}
 		}
@@ -186,7 +187,7 @@ function form_save() {
 				raise_message(1);
 
 				push_out_graph($graph_template_graph_id);
-			}else{
+			} else {
 				raise_message(2);
 			}
 		}
@@ -215,50 +216,50 @@ function form_actions() {
 		$selected_items = sanitize_unserialize_selected_items(get_nfilter_request_var('selected_items'));
 
 		if ($selected_items != false) {
-			if (get_request_var('drp_action') == '1') { /* delete */
-				db_execute('DELETE FROM graph_templates 
+			if (get_request_var('drp_action') == '1') { // delete
+				db_execute('DELETE FROM graph_templates
 					WHERE ' . array_to_sql_or($selected_items, 'id'));
 
-				$graph_template_input = db_fetch_assoc('SELECT id 
-					FROM graph_template_input 
+				$graph_template_input = db_fetch_assoc('SELECT id
+					FROM graph_template_input
 					WHERE ' . array_to_sql_or($selected_items, 'graph_template_id'));
 
 				if (sizeof($graph_template_input) > 0) {
 					foreach ($graph_template_input as $item) {
-						db_execute_prepared('DELETE FROM graph_template_input_defs 
+						db_execute_prepared('DELETE FROM graph_template_input_defs
 							WHERE graph_template_input_id = ?', array($item['id']));
 					}
 				}
 
-				db_execute('DELETE FROM graph_template_input 
+				db_execute('DELETE FROM graph_template_input
 					WHERE ' . array_to_sql_or($selected_items, 'graph_template_id'));
 
-				db_execute('DELETE FROM graph_templates_graph 
+				db_execute('DELETE FROM graph_templates_graph
 					WHERE ' . array_to_sql_or($selected_items, 'graph_template_id') . ' AND local_graph_id=0');
 
-				db_execute('DELETE FROM graph_templates_item 
+				db_execute('DELETE FROM graph_templates_item
 					WHERE ' . array_to_sql_or($selected_items, 'graph_template_id') . ' AND local_graph_id=0');
 
-				db_execute('DELETE FROM host_template_graph 
+				db_execute('DELETE FROM host_template_graph
 					WHERE ' . array_to_sql_or($selected_items, 'graph_template_id'));
 
 				/* 'undo' any graph that is currently using this template */
-				db_execute('UPDATE graph_templates_graph 
-					SET local_graph_template_graph_id=0, graph_template_id=0 
+				db_execute('UPDATE graph_templates_graph
+					SET local_graph_template_graph_id=0, graph_template_id=0
 					WHERE ' . array_to_sql_or($selected_items, 'graph_template_id'));
 
-				db_execute('UPDATE graph_templates_item 
-					SET local_graph_template_item_id=0, graph_template_id=0 
+				db_execute('UPDATE graph_templates_item
+					SET local_graph_template_item_id=0, graph_template_id=0
 					WHERE ' . array_to_sql_or($selected_items, 'graph_template_id'));
 
-				db_execute('UPDATE graph_local 
-					SET graph_template_id=0 
+				db_execute('UPDATE graph_local
+					SET graph_template_id=0
 					WHERE ' . array_to_sql_or($selected_items, 'graph_template_id'));
-			}elseif (get_request_var('drp_action') == '2') { /* duplicate */
+			} elseif (get_request_var('drp_action') == '2') { // duplicate
 				for ($i=0;($i<count($selected_items));$i++) {
 					api_duplicate_graph(0, $selected_items[$i], get_nfilter_request_var('title_format'));
 				}
-			}elseif (get_request_var('drp_action') == '3') { /* resize */
+			} elseif (get_request_var('drp_action') == '3') { // resize
 				get_filter_request_var('graph_width');
 				get_filter_request_var('graph_height');
 
@@ -266,11 +267,11 @@ function form_actions() {
 					db_execute_prepared('UPDATE graph_templates_graph
 						SET width = ?, height = ?
 						WHERE graph_template_id = ?',
-						array(get_request_var('graph_width'), 
-						get_request_var('graph_height'), 
+						array(get_request_var('graph_width'),
+						get_request_var('graph_height'),
 						$selected_items[$i]));
 				}
-			}elseif (get_request_var('drp_action') == '4') { /* retemplate */
+			} elseif (get_request_var('drp_action') == '4') { // retemplate
 				for ($i=0;($i<count($selected_items));$i++) {
 					retemplate_graphs($selected_items[$i]);
 				}
@@ -285,7 +286,7 @@ function form_actions() {
 	$graph_list = ''; $i = 0;
 
 	/* loop through each of the graphs selected on the previous page and get more info about them */
-	while (list($var,$val) = each($_POST)) {
+	foreach ($_POST as $var => $val) {
 		if (preg_match('/^chk_([0-9]+)$/', $var, $matches)) {
 			/* ================= input validation ================= */
 			input_validate_input_number($matches[1]);
@@ -302,10 +303,10 @@ function form_actions() {
 
 	form_start('graph_templates.php');
 
-	html_start_box($graph_actions{get_nfilter_request_var('drp_action')}, '60%', '', '3', 'center', '');
+	html_start_box($graph_actions[get_nfilter_request_var('drp_action')], '60%', '', '3', 'center', '');
 
 	if (isset($graph_array) && sizeof($graph_array)) {
-		if (get_request_var('drp_action') == '1') { /* delete */
+		if (get_request_var('drp_action') == '1') { // delete
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Click \'Continue\' to delete the following Graph Template(s).  Any Graph(s) associated with the Template(s) will become individual Graph(s).') . "</p>
@@ -313,8 +314,8 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Delete Graph Template(s)') . "'>";
-		}elseif (get_request_var('drp_action') == '2') { /* duplicate */
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Delete Graph Template(s)') . "'>";
+		} elseif (get_request_var('drp_action') == '2') { // duplicate
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Click \'Continue\' to duplicate the following Graph Template(s). You can optionally change the title format for the new Graph Template(s).') . "</p>
@@ -323,8 +324,8 @@ function form_actions() {
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue'). "' title='" . __('Duplicate Graph Template(s)') . "'>";
-		}elseif (get_request_var('drp_action') == '3') { /* resize */
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue'). "' title='" . __esc('Duplicate Graph Template(s)') . "'>";
+		} elseif (get_request_var('drp_action') == '3') { // resize
 			print "<tr>
 				<td class='textArea'>
 					<p>" . __('Click \'Continue\' to resize the following Graph Template(s) and Graph(s) to the Height and Width below.  The defaults below are maintained in Settings.') . "</p>
@@ -343,20 +344,20 @@ function form_actions() {
 
 			print "</td></tr></table><div class='break'></div><table style='width:100%'>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue') . "' title='" . __('Resize Selected Graph Template(s)') . "'>";
-		}elseif (get_request_var('drp_action') == '4') { /* retemplate */
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue') . "' title='" . __esc('Resize Selected Graph Template(s)') . "'>";
+		} elseif (get_request_var('drp_action') == '4') { // retemplate
 			print "<tr>
 				<td class='textArea'>
-					<p>" . __('Click \'Continue\' to Synchronize your Graphs the following Graph Template(s). This function is important if you have Graphs that exist with multiple versions of a Graph Template and wish to make them all common in appearance.') . "</p>
+					<p>" . __('Click \'Continue\' to Synchronize your Graphs with the following Graph Template(s). This function is important if you have Graphs that exist with multiple versions of a Graph Template and wish to make them all common in appearance.') . "</p>
 					<div class='itemlist'><ul>$graph_list</ul></div>
 				</td>
 			</tr>\n";
 
-			$save_html = "<input type='button' value='" . __('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __('Continue'). "' title='" . __('Synchronize Graphs to Graph Template(s)') . "'>";
+			$save_html = "<input type='button' value='" . __esc('Cancel') . "' onClick='cactiReturnTo()'>&nbsp;<input type='submit' value='" . __esc('Continue'). "' title='" . __esc('Synchronize Graphs to Graph Template(s)') . "'>";
 		}
-	}else{
+	} else {
 		print "<tr><td class='even'><p><span class='textError'>" . __('ERROR: You must select at least one graph template.') . "</span></p></td></tr>\n";
-		$save_html = "<input type='button' value='" . __('Return') . "' onClick='cactiReturnTo()'>";
+		$save_html = "<input type='button' value='" . __esc('Return') . "' onClick='cactiReturnTo()'>";
 	}
 
 	print "<tr>
@@ -386,27 +387,27 @@ function item() {
 		$template_item_list = array();
 
 		$header_label = 'Graph Template Items [new]';
-	}else{
+	} else {
 		$template_item_list = db_fetch_assoc_prepared("SELECT gti.id, gti.text_format, gti.alpha,
-			gti.value, gti.hard_return, gti.graph_type_id, gti.consolidation_function_id,
+			gti.value, gti.hard_return, gti.graph_type_id, gti.consolidation_function_id, gti.textalign,
 			CONCAT_WS(' - ', dtd.name, dtr.data_source_name) AS data_source_name,
 			cdef.name AS cdef_name, colors.hex
 			FROM graph_templates_item AS gti
 			LEFT JOIN data_template_rrd AS dtr
 			ON gti.task_item_id=dtr.id
-			LEFT JOIN data_local AS dl 
+			LEFT JOIN data_local AS dl
 			ON dtr.local_data_id=dl.id
 			LEFT JOIN data_template_data AS dtd
 			ON dl.id=dtd.local_data_id
-			LEFT JOIN cdef 
+			LEFT JOIN cdef
 			ON cdef_id=cdef.id
-			LEFT JOIN vdef 
+			LEFT JOIN vdef
 			ON vdef_id=vdef.id
-			LEFT JOIN colors 
+			LEFT JOIN colors
 			ON color_id=colors.id
 			WHERE gti.graph_template_id = ?
 			AND gti.local_graph_id=0
-			ORDER BY gti.sequence", 
+			ORDER BY gti.sequence",
 			array(get_request_var('id')));
 
 		$header_label = __('Graph Template Items [edit: %s]', htmlspecialchars(db_fetch_cell_prepared('SELECT name FROM graph_templates WHERE id = ?', array(get_request_var('id')))));
@@ -422,8 +423,8 @@ function item() {
 		DrawMatrixHeaderItem(__('Name'),'',2);
 	print '</tr>';
 
-	$template_item_list = db_fetch_assoc_prepared('SELECT id, name 
-		FROM graph_template_input 
+	$template_item_list = db_fetch_assoc_prepared('SELECT id, name
+		FROM graph_template_input
 		WHERE graph_template_id = ?
 		ORDER BY name', array(get_request_var('id')));
 
@@ -435,13 +436,13 @@ function item() {
 			<td>
 				<a class='linkEditMain' href='<?php print htmlspecialchars('graph_templates_inputs.php?action=input_edit&id=' . $item['id'] . '&graph_template_id=' . get_request_var('id'));?>'><?php print htmlspecialchars($item['name']);?></a>
 			</td>
-			<td align='right'>
-				<a class='deleteMarker fa fa-remove' title='<?php print __('Delete');?>' href='<?php print htmlspecialchars('graph_templates_inputs.php?action=input_remove&id=' . $item['id'] . '&graph_template_id=' . get_request_var('id'));?>'></a>
+			<td class='right'>
+				<a class='deleteMarker fa fa-remove' title='<?php print __esc('Delete');?>' href='<?php print htmlspecialchars('graph_templates_inputs.php?action=input_remove&id=' . $item['id'] . '&graph_template_id=' . get_request_var('id'));?>'></a>
 			</td>
 		</tr>
 		<?php
 		}
-	}else{
+	} else {
 		print "<tr><td colspan='2'><em>" . __('No Inputs') . "</em></td></tr>";
 	}
 
@@ -476,25 +477,25 @@ function template_edit() {
 	}
 
 	if (!isempty_request_var('id')) {
-		$template       = db_fetch_row_prepared('SELECT * 
-			FROM graph_templates 
-			WHERE id = ?', 
+		$template       = db_fetch_row_prepared('SELECT *
+			FROM graph_templates
+			WHERE id = ?',
 			array(get_request_var('id')));
 
-		$template_graph = db_fetch_row_prepared('SELECT * 
-			FROM graph_templates_graph 
+		$template_graph = db_fetch_row_prepared('SELECT *
+			FROM graph_templates_graph
 			WHERE graph_template_id = ?
 			AND local_graph_id=0',
 			array(get_request_var('id')));
 
 		$header_label = __('Template [edit: %s]', htmlspecialchars($template['name']));
-	}else{
+	} else {
 		$header_label = __('Template [new]');
 	}
 
 	form_start('graph_templates.php', 'graph_templates');
 
-	html_start_box($header_label, '100%', '', '3', 'center', '');
+	html_start_box($header_label, '100%', true, '3', 'center', '');
 
 	draw_edit_form(
 		array(
@@ -503,13 +504,13 @@ function template_edit() {
 		)
 	);
 
-	html_end_box();
+	html_end_box(true, true);
 
-	html_start_box(__('Graph Template Options'), '100%', '', '3', 'center', '');
+	html_start_box(__('Graph Template Options'), '100%', true, '3', 'center', '');
 
 	$form_array = array();
 
-	while (list($field_name, $field_array) = each($struct_graph)) {
+	foreach ($struct_graph as $field_name => $field_array) {
 		$form_array += array($field_name => $struct_graph[$field_name]);
 
 		if ($form_array[$field_name]['method'] != 'spacer') {
@@ -521,7 +522,7 @@ function template_edit() {
 			$form_array[$field_name]['sub_checkbox'] = array(
 				'name' => 't_' . $field_name,
 				'friendly_name' => __('Use Per-Graph Value (Ignore this Value)'),
-				'value' => (isset($template_graph['t_' . $field_name]) ? $template_graph{'t_' . $field_name} : '')
+				'value' => (isset($template_graph['t_' . $field_name]) ? $template_graph['t_' . $field_name] : '')
 			);
 		}
 	}
@@ -534,7 +535,8 @@ function template_edit() {
 	);
 
 	form_hidden_box('rrdtool_version', read_config_option('rrdtool_version'), '');
-	html_end_box();
+
+	html_end_box(true, true);
 
 	form_save_button('graph_templates.php', 'return');
 
@@ -573,32 +575,32 @@ function template() {
 	/* ================= input validation and session storage ================= */
 	$filters = array(
 		'rows' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'pageset' => true,
 			'default' => '-1'
 			),
 		'page' => array(
-			'filter' => FILTER_VALIDATE_INT, 
+			'filter' => FILTER_VALIDATE_INT,
 			'default' => '1'
 			),
 		'filter' => array(
-			'filter' => FILTER_CALLBACK, 
+			'filter' => FILTER_CALLBACK,
 			'pageset' => true,
-			'default' => '', 
+			'default' => '',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_column' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'name', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'name',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'sort_direction' => array(
-			'filter' => FILTER_CALLBACK, 
-			'default' => 'ASC', 
+			'filter' => FILTER_CALLBACK,
+			'default' => 'ASC',
 			'options' => array('options' => 'sanitize_search_string')
 			),
 		'has_graphs' => array(
-			'filter' => FILTER_VALIDATE_REGEXP, 
+			'filter' => FILTER_VALIDATE_REGEXP,
 			'options' => array('options' => array('regexp' => '(true|false)')),
 			'pageset' => true,
 			'default' => read_config_option('default_has') == 'on' ? 'true':'false'
@@ -610,7 +612,7 @@ function template() {
 
 	if (get_request_var('rows') == '-1') {
 		$rows = read_config_option('num_rows_table');
-	}else{
+	} else {
 		$rows = get_request_var('rows');
 	}
 
@@ -626,16 +628,16 @@ function template() {
 						<?php print __('Search');?>
 					</td>
 					<td>
-						<input id='filter' type='text' name='filter' size='25' value='<?php print htmlspecialchars(get_request_var('filter'));?>'>
+						<input id='filter' type='text' name='filter' size='25' value='<?php print html_escape_request_var('filter');?>'>
 					</td>
-					<td class='nowrap'>
+					<td>
 						<?php print __('Graph Templates');?>
 					</td>
 					<td>
 						<select id='rows' name='rows' onChange='applyFilter()'>
 							<option value='-1'<?php print (get_request_var('rows') == '-1' ? ' selected>':'>') . __('Default');?></option>
 							<?php
-							if (sizeof($item_rows) > 0) {
+							if (sizeof($item_rows)) {
 								foreach ($item_rows as $key => $value) {
 									print "<option value='" . $key . "'"; if (get_request_var('rows') == $key) { print ' selected'; } print '>' . htmlspecialchars($value) . "</option>\n";
 								}
@@ -644,26 +646,28 @@ function template() {
 						</select>
 					</td>
 					<td>
-						<input type='checkbox' id='has_graphs' <?php print (get_request_var('has_graphs') == 'true' ? 'checked':'');?>>
+						<span>
+							<input type='checkbox' id='has_graphs' <?php print (get_request_var('has_graphs') == 'true' ? 'checked':'');?>>
+							<label for='has_graphs'><?php print __('Has Graphs');?></label>
+						</span>
 					</td>
 					<td>
-						<label for='has_graphs'><?php print __('Has Graphs');?></label>
-					</td>
-					<td>
-						<input type='button' id='refresh' value='<?php print __('Go');?>' title='<?php print __('Set/Refresh Filters');?>'>
-					</td>
-					<td>
-						<input type='button' id='clear' value='<?php print __('Clear');?>' title='<?php print __('Clear Filters');?>'>
+						<span>
+							<input type='button' id='refresh' value='<?php print __esc('Go');?>' title='<?php print __esc('Set/Refresh Filters');?>'>
+							<input type='button' id='clear' value='<?php print __esc('Clear');?>' title='<?php print __esc('Clear Filters');?>'>
+						</span>
 					</td>
 				</tr>
 			</table>
-			<input type='hidden' id='page' name='page' value='<?php print get_request_var('page');?>'>
 		</form>
 		<script type='text/javascript'>
 		var disabled = true;
 
 		function applyFilter() {
-			strURL = 'graph_templates.php?filter='+$('#filter').val()+'&rows='+$('#rows').val()+'&page='+$('#page').val()+'&has_graphs='+$('#has_graphs').is(':checked')+'&header=false';
+			strURL  = 'graph_templates.php?header=false';
+			strURL += '&filter='+$('#filter').val();
+			strURL += '&rows='+$('#rows').val();
+			strURL += '&has_graphs='+$('#has_graphs').is(':checked');
 			loadPageNoHeader(strURL);
 		}
 
@@ -684,7 +688,7 @@ function template() {
 			$('#clear').click(function() {
 				clearFilter();
 			});
-	
+
 			$('#form_graph_template').submit(function(event) {
 				event.preventDefault();
 				applyFilter();
@@ -700,25 +704,25 @@ function template() {
 	/* form the 'where' clause for our main sql query */
 	if (get_request_var('filter') != '') {
 		$sql_where = "WHERE (gt.name LIKE '%" . get_request_var('filter') . "%')";
-	}else{
+	} else {
 		$sql_where = '';
 	}
 
 	if (get_request_var('has_graphs') == 'true') {
 		$sql_having = 'HAVING graphs>0';
-	}else{
+	} else {
 		$sql_having = '';
 	}
 
-	$total_rows = db_fetch_cell("SELECT COUNT(rows)
+	$total_rows = db_fetch_cell("SELECT COUNT(`rows`)
 		FROM (SELECT
-			COUNT(gt.id) AS rows,
+			COUNT(gt.id) AS `rows`,
 			COUNT(gl.id) AS graphs
 			FROM graph_templates AS gt
 			LEFT JOIN graph_local AS gl
 			ON gt.id=gl.graph_template_id
 			INNER JOIN (
-				SELECT * 
+				SELECT *
 				FROM graph_templates_graph AS gtg
 				WHERE gtg.local_graph_id=0
 			) AS gtg
@@ -732,8 +736,8 @@ function template() {
 	$sql_limit = ' LIMIT ' . ($rows*(get_request_var('page')-1)) . ',' . $rows;
 
 	$template_list = db_fetch_assoc("SELECT
-		gt.id, gt.name, gl.snmp_query_id AS dqid, 
-		CONCAT(gtg.height,'x',gtg.width) AS size, gtg.vertical_label, 
+		gt.id, gt.name, gl.snmp_query_id AS dqid,
+		CONCAT(gtg.height,'x',gtg.width) AS size, gtg.vertical_label,
 		gtg.image_format_id, COUNT(gl.id) AS graphs
 		FROM graph_templates AS gt
 		INNER JOIN graph_templates_graph AS gtg
@@ -772,7 +776,7 @@ function template() {
 		foreach ($template_list as $template) {
 			if ($template['graphs'] > 0) {
 				$disabled = true;
-			}else{
+			} else {
 				$disabled = false;
 			}
 			form_alternate_row('line' . $template['id'], true, $disabled);
@@ -787,7 +791,7 @@ function template() {
 			form_checkbox_cell($template['name'], $template['id'], $disabled);
 			form_end_row();
 		}
-	}else{
+	} else {
 		print "<tr class='tableRow'><td colspan='4'><em>" . __('No Graph Templates Found') . "</em></td></tr>\n";
 	}
 	html_end_box(false);
