@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -22,7 +22,12 @@
  +-------------------------------------------------------------------------+
 */
 
-function upgrade_to_1_1_14() {
-	db_install_execute('ALTER TABLE automation_networks
-		MODIFY COLUMN subnet_range VARCHAR(1024) NOT NULL DEFAULT ""');
+function upgrade_to_1_1_11() {
+	db_install_execute('ALTER TABLE poller_data_template_field_mappings
+		MODIFY COLUMN data_name VARCHAR(40) NOT NULL DEFAULT "",
+		MODIFY COLUMN data_source_names VARCHAR(125) NOT NULL DEFAULT ""');
+
+	// required for tne new plugin structure
+	db_install_execute('DELETE FROM settings WHERE name LIKE "md5%_plugins"');
+	db_install_execute('DELETE FROM poller_resource_cache WHERE path LIKE "plugins/%"');
 }
