@@ -1,7 +1,7 @@
 <?php
 /*
  +-------------------------------------------------------------------------+
- | Copyright (C) 2004-2017 The Cacti Group                                 |
+ | Copyright (C) 2004-2018 The Cacti Group                                 |
  |                                                                         |
  | This program is free software; you can redistribute it and/or           |
  | modify it under the terms of the GNU General Public License             |
@@ -36,16 +36,59 @@ case 'save':
 			/* do nothing */
 		} elseif ($field_array['method'] == 'checkbox') {
 			if (isset_request_var($field_name)) {
-				db_execute_prepared("REPLACE INTO settings (name, value) VALUES (?, 'on')", array($field_name));
+				db_execute_prepared("REPLACE INTO settings
+					(name, value)
+					VALUES (?, 'on')",
+					array($field_name));
 			} else {
-				db_execute_prepared("REPLACE INTO settings (name, value) VALUES (?, '')", array($field_name));
+				db_execute_prepared("REPLACE INTO settings
+					(name, value)
+					VALUES (?, '')",
+					array($field_name));
 			}
 		} elseif ($field_array['method'] == 'checkbox_group') {
 			foreach ($field_array['items'] as $sub_field_name => $sub_field_array) {
 				if (isset_request_var($sub_field_name)) {
-					db_execute_prepared("REPLACE INTO settings (name, value) VALUES (?, 'on')", array($sub_field_name));
+					db_execute_prepared("REPLACE INTO settings
+					(name, value)
+					VALUES (?, 'on')",
+					array($sub_field_name));
 				} else {
-					db_execute_prepared("REPLACE INTO settings (name, value) VALUES (?, '')", array($sub_field_name));
+					db_execute_prepared("REPLACE INTO settings
+					(name, value)
+					VALUES (?, '')",
+					array($sub_field_name));
+				}
+			}
+		} elseif ($field_array['method'] == 'dirpath') {
+			if (get_nfilter_request_var($field_name) != '' && !is_dir(get_nfilter_request_var($field_name))) {
+				raise_message(8);
+			} else {
+				db_execute_prepared('REPLACE INTO settings
+					(name, value)
+					VALUES (?, ?)',
+					array($field_name, get_nfilter_request_var($field_name)));
+			}
+		} elseif ($field_array['method'] == 'filepath') {
+			if (get_nfilter_request_var($field_name) != '' && !is_file(get_nfilter_request_var($field_name))) {
+				raise_message(8);
+			} else {
+				$continue = true;
+
+				if ($field_name == 'path_cactilog') {
+					$extension = pathinfo(get_nfilter_request_var($field_name), PATHINFO_EXTENSION);
+
+					if ($extension != 'log') {
+						raise_message(9);
+						$continue = false;
+					}
+				}
+
+				if ($continue) {
+					db_execute_prepared('REPLACE INTO settings
+						(name, value)
+						VALUES (?, ?)',
+						array($field_name, get_nfilter_request_var($field_name)));
 				}
 			}
 		} elseif ($field_array['method'] == 'textbox_password') {
@@ -53,40 +96,65 @@ case 'save':
 				raise_message(4);
 				break;
 			} elseif (!isempty_request_var($field_name)) {
-				db_execute_prepared('REPLACE INTO settings (name, value) VALUES (?, ?)', array($field_name, get_nfilter_request_var($field_name)));
+				db_execute_prepared('REPLACE INTO settings
+					(name, value)
+					VALUES (?, ?)',
+					array($field_name, get_nfilter_request_var($field_name)));
 			}
 		} elseif ((isset($field_array['items'])) && (is_array($field_array['items']))) {
 			foreach ($field_array['items'] as $sub_field_name => $sub_field_array) {
 				if (isset_request_var($sub_field_name)) {
-					db_execute_prepared('REPLACE INTO settings (name, value) VALUES (?, ?)', array($sub_field_name, get_nfilter_request_var($sub_field_name)));
+					db_execute_prepared('REPLACE INTO settings
+					(name, value)
+					VALUES (?, ?)',
+					array($sub_field_name, get_nfilter_request_var($sub_field_name)));
 				}
 			}
 		} elseif ($field_array['method'] == 'drop_multi') {
 			if (isset_request_var($field_name)) {
 				if (is_array(get_nfilter_request_var($field_name))) {
-					db_execute_prepared('REPLACE INTO settings (name, value) VALUES (?, ?)', array($field_name, implode(',', get_nfilter_request_var($field_name))));
+					db_execute_prepared('REPLACE INTO settings
+					(name, value)
+					VALUES (?, ?)',
+					array($field_name, implode(',', get_nfilter_request_var($field_name))));
 				} else {
-					db_execute_prepared('REPLACE INTO settings (name, value) VALUES (?, ?)', array($field_name, get_nfilter_request_var($field_name)));
+					db_execute_prepared('REPLACE INTO settings
+					(name, value)
+					VALUES (?, ?)',
+					array($field_name, get_nfilter_request_var($field_name)));
 				}
 			} else {
-				db_execute_prepared('REPLACE INTO settings (name, value) VALUES (?, "")', array($field_name));
+				db_execute_prepared('REPLACE INTO settings
+					(name, value)
+					VALUES (?, "")',
+					array($field_name));
 			}
 		} elseif (isset_request_var($field_name)) {
 			if (is_array(get_nfilter_request_var($field_name))) {
-				db_execute_prepared('REPLACE INTO settings (name, value) VALUES (?, ?)', array($field_name, implode(',', get_nfilter_request_var($field_name))));
+				db_execute_prepared('REPLACE INTO settings
+					(name, value)
+					VALUES (?, ?)',
+					array($field_name, implode(',', get_nfilter_request_var($field_name))));
 			} else {
-				db_execute_prepared('REPLACE INTO settings (name, value) VALUES (?, ?)', array($field_name, get_nfilter_request_var($field_name)));
+				db_execute_prepared('REPLACE INTO settings
+					(name, value)
+					VALUES (?, ?)',
+					array($field_name, get_nfilter_request_var($field_name)));
 			}
 		}
 	}
 
 	if (isset_request_var('log_verbosity')) {
 		if (!isset_request_var('selective_debug')) {
-			db_execute('REPLACE INTO settings (name, value) VALUES("selective_debug", "")');
+			db_execute('REPLACE INTO settings
+				(name, value)
+				VALUES ("selective_debug", "")');
 		}
 
 		if (!isset_request_var('selective_plugin_debug')) {
-			db_execute('REPLACE INTO settings (name, value) VALUES("selective_plugin_debug", "")');
+			db_execute('REPLACE INTO settings
+				(name, value)
+				VALUES ("selective_plugin_debug", "")');
 		}
 	}
 
@@ -134,7 +202,7 @@ default:
 		$i = 0;
 
 		foreach (array_keys($tabs) as $tab_short_name) {
-			print "<li class='subTab'><a " . (($tab_short_name == $current_tab) ? "class='selected'" : "class=''") . " href='" . htmlspecialchars("settings.php?tab=$tab_short_name") . "'>" . $tabs[$tab_short_name] . "</a></li>\n";
+			print "<li class='subTab'><a " . (($tab_short_name == $current_tab) ? "class='selected'" : "class=''") . " href='" . html_escape("settings.php?tab=$tab_short_name") . "'>" . $tabs[$tab_short_name] . "</a></li>\n";
 
 			$i++;
 		}
@@ -361,10 +429,13 @@ default:
 			});
 		}
 
-		if ($('#row_snmp_ver')) {
-			initSNMP();
-			$('#snmp_ver').change(function() {
-				initSNMP();
+		if ($('#row_snmp_version')) {
+			// Need to set this for global snmpv3 functions to remain sane between edits
+			snmp_security_initialized = false;
+
+			setSNMP();
+			$('#snmp_version, #snmp_auth_protocol, #snmp_priv_protocol, #snmp_security_level').change(function() {
+				setSNMP();
 			});
 		}
 
@@ -905,53 +976,10 @@ default:
 		}
 	}
 
-	function initSNMP() {
-		/* clear passwords */
-		$('#snmp_password').val('');
-		$('#snmp_password_confirm').val('');
-
-		switch($('#snmp_ver').val()) {
-		case "0":
-			$('#row_snmp_community').hide();
-			$('#row_snmp_username').hide();
-			$('#row_snmp_password').hide();
-			$('#row_snmp_auth_protocol').hide();
-			$('#row_snmp_priv_passphrase').hide();
-			$('#row_snmp_priv_protocol').hide();
-			$('#row_snmp_timeout').hide();
-			$('#row_snmp_port').hide();
-			$('#row_snmp_retries').hide();
-			break;
-		case "1":
-		case "2":
-			$('#row_snmp_community').show();
-			$('#row_snmp_username').hide();
-			$('#row_snmp_password').hide();
-			$('#row_snmp_auth_protocol').hide();
-			$('#row_snmp_priv_passphrase').hide();
-			$('#row_snmp_priv_protocol').hide();
-			$('#row_snmp_timeout').show();
-			$('#row_snmp_port').show();
-			$('#row_snmp_retries').show();
-			break;
-		case "3":
-			$('#row_snmp_community').hide();
-			$('#row_snmp_username').show();
-			$('#row_snmp_password').show();
-			$('#row_snmp_auth_protocol').show();
-			$('#row_snmp_priv_passphrase').show();
-			$('#row_snmp_priv_protocol').show();
-			$('#row_snmp_timeout').show();
-			$('#row_snmp_port').show();
-			$('#row_snmp_retries').show();
-			break;
-		}
-	}
-
 	function initFTPExport() {
 		switch($('#export_type').val()) {
-		case "disabled":
-		case "local":
+		case 'disabled':
+		case 'local':
 			$('#row_export_hdr_ftp').hide();
 			$('#row_export_ftp_sanitize').hide();
 			$('#row_export_ftp_host').hide();
@@ -960,9 +988,9 @@ default:
 			$('#row_export_ftp_user').hide();
 			$('#row_export_ftp_password').hide();
 			break;
-		case "ftp_php":
-		case "ftp_ncftpput":
-		case "sftp_php":
+		case 'ftp_php':
+		case 'ftp_ncftpput':
+		case 'sftp_php':
 			$('#row_export_hdr_ftp').show();
 			$('#row_export_ftp_sanitize').show();
 			$('#row_export_ftp_host').show();
@@ -976,12 +1004,12 @@ default:
 
 	function initPresentation() {
 		switch($('#export_presentation').val()) {
-		case "classical":
+		case 'classical':
 			$('#row_export_tree_options').hide();
 			$('#row_export_tree_isolation').hide();
 			$('#row_export_tree_expand_hosts').hide();
 			break;
-		case "tree":
+		case 'tree':
 			$('#row_export_tree_options').show();
 			$('#row_export_tree_isolation').show();
 			$('#row_export_tree_expand_hosts').show();
@@ -991,22 +1019,22 @@ default:
 
 	function initTiming() {
 		switch($('#export_timing').val()) {
-		case "disabled":
+		case 'disabled':
 			$('#row_path_html_export_skip').hide();
 			$('#row_export_hourly').hide();
 			$('#row_export_daily').hide();
 			break;
-		case "classic":
+		case 'classic':
 			$('#row_path_html_export_skip').show();
 			$('#row_export_hourly').hide();
 			$('#row_export_daily').hide();
 			break;
-		case "export_hourly":
+		case 'export_hourly':
 			$('#row_path_html_export_skip').hide();
 			$('#row_export_hourly').show();
 			$('#row_export_daily').hide();
 			break;
-		case "export_daily":
+		case 'export_daily':
 			$('#row_path_html_export_skip').hide();
 			$('#row_export_hourly').hide();
 			$('#row_export_daily').show();
